@@ -97,6 +97,8 @@ typedef enum {
 	GS_PLUGIN_REFINE_FLAGS_REQUIRE_RELATED		= 1 << 11,
 	GS_PLUGIN_REFINE_FLAGS_REQUIRE_MENU_PATH	= 1 << 12,
 	GS_PLUGIN_REFINE_FLAGS_REQUIRE_ADDONS		= 1 << 13,
+	GS_PLUGIN_REFINE_FLAGS_ALLOW_PACKAGES		= 1 << 14,
+	GS_PLUGIN_REFINE_FLAGS_ALLOW_NO_APPDATA		= 1 << 15,
 	GS_PLUGIN_REFINE_FLAGS_LAST
 } GsPluginRefineFlags;
 
