@@ -676,6 +676,9 @@ gs_shell_extras_load (GsShellExtras *shell_extras, GPtrArray *array_search_data)
 	/* remove old entries */
 	gs_container_remove_all (GTK_CONTAINER (priv->list_box_results));
 
+	/* set state as loading */
+	priv->state = GS_SHELL_EXTRAS_STATE_LOADING;
+
 	/* start new searches, separate one for each codec */
 	for (i = 0; i < priv->array_search_data->len; i++) {
 		SearchData *search_data;
@@ -686,7 +689,9 @@ gs_shell_extras_load (GsShellExtras *shell_extras, GPtrArray *array_search_data)
 			gs_plugin_loader_search_files_async (priv->plugin_loader,
 			                                     search_data->search_filename,
 			                                     GS_PLUGIN_REFINE_FLAGS_DEFAULT |
-			                                     GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING,
+			                                     GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
+			                                     GS_PLUGIN_REFINE_FLAGS_ALLOW_PACKAGES |
+			                                     GS_PLUGIN_REFINE_FLAGS_ALLOW_NO_APPDATA,
 			                                     priv->search_cancellable,
 			                                     search_files_cb,
 			                                     search_data);
@@ -695,7 +700,9 @@ gs_shell_extras_load (GsShellExtras *shell_extras, GPtrArray *array_search_data)
 			gs_plugin_loader_filename_to_app_async (priv->plugin_loader,
 			                                        search_data->package_filename,
 			                                        GS_PLUGIN_REFINE_FLAGS_DEFAULT |
-			                                        GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING,
+			                                        GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
+			                                        GS_PLUGIN_REFINE_FLAGS_ALLOW_PACKAGES |
+			                                        GS_PLUGIN_REFINE_FLAGS_ALLOW_NO_APPDATA,
 			                                        priv->search_cancellable,
 			                                        filename_to_app_cb,
 			                                        search_data);
@@ -708,7 +715,9 @@ gs_shell_extras_load (GsShellExtras *shell_extras, GPtrArray *array_search_data)
 			                                             GS_PLUGIN_REFINE_FLAGS_REQUIRE_HISTORY |
 			                                             GS_PLUGIN_REFINE_FLAGS_REQUIRE_SETUP_ACTION |
 			                                             GS_PLUGIN_REFINE_FLAGS_REQUIRE_DESCRIPTION |
-			                                             GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING,
+			                                             GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
+			                                             GS_PLUGIN_REFINE_FLAGS_ALLOW_PACKAGES |
+			                                             GS_PLUGIN_REFINE_FLAGS_ALLOW_NO_APPDATA,
 			                                             priv->search_cancellable,
 			                                             get_search_what_provides_cb,
 			                                             search_data);
@@ -918,7 +927,7 @@ gs_shell_extras_search_printer_drivers (GsShellExtras *shell_extras, gchar **dev
 		tag = g_strconcat (mfg, ";", mdl, ";", NULL);
 
 		search_data = g_slice_new0 (SearchData);
-		search_data->title = g_strdup (tag);
+		search_data->title = g_strdup_printf ("%s %s", mfg, mdl);
 		search_data->search = g_ascii_strdown (tag, -1);
 
 		/* Replace spaces with underscores */
